@@ -1,19 +1,19 @@
 import autoarray as aa
 import autoarray.plot as aplt
 
-array = aa.array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
+array = aa.Array.ones(shape_2d=(31, 31), pixel_scales=(1.0, 1.0), sub_size=2)
 array[0] = 3.0
 
-mask = aa.mask.circular(
+mask = aa.Mask.circular(
     shape_2d=array.shape_2d,
     pixel_scales=array.pixel_scales,
     radius=5.0,
     centre=(2.0, 2.0),
 )
 
-grid = aa.grid.uniform(shape_2d=(11, 11), pixel_scales=0.5)
+grid = aa.Grid.uniform(shape_2d=(11, 11), pixel_scales=0.5)
 
-aplt.array(
+aplt.Array(
     array=array,
     mask=mask,
     grid=grid,
@@ -23,7 +23,7 @@ aplt.array(
     include_border=True,
 )
 
-aplt.array(
+aplt.Array(
     array=array,
     mask=mask,
     grid=grid,
