@@ -52,11 +52,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular(
+            pixelization_grid = aa.GridRectangular(
                 grid=np.ones((2, 2)), shape_2d=(3, 3), pixel_scales=(1.0, 1.0)
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -97,11 +97,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -140,11 +140,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -190,11 +190,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(4, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -242,11 +242,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 4), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -280,11 +280,11 @@ class TestRectangularMapper:
                 [[1.5, -1.5], [1.0, 0.0], [1.0, 0.6], [-1.4, 0.0], [-1.5, 1.5]]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -313,11 +313,11 @@ class TestRectangularMapper:
                 [[1.0, -1.5], [1.0, -0.49], [0.32, -1.5], [0.32, 0.51], [-1.0, 1.5]]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -347,11 +347,11 @@ class TestRectangularMapper:
                 [[1.0, -1.5], [1.0, -0.49], [0.49, -1.5], [-0.6, 0.0], [-1.0, 1.5]]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(4, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -383,11 +383,11 @@ class TestRectangularMapper:
                 [[1.0, -1.5], [1.0, -0.49], [0.32, -1.5], [-0.34, 0.49], [-1.0, 1.5]]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 4), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -429,11 +429,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -474,11 +474,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -508,11 +508,11 @@ class TestRectangularMapper:
                 [[3.0, -0.5], [3.0, 0.51], [2.49, -0.5], [1.4, 1.0], [1.0, 2.5]]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(4, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -549,11 +549,11 @@ class TestRectangularMapper:
                 ]
             )
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid
             )
 
-            mapper = aa.mapper(grid=grid, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
 
             recon_pix = mapper.reconstructed_pixelization_from_solution_vector(
                 solution_vector=np.array([1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0])
@@ -568,11 +568,11 @@ class TestRectangularMapper:
 
         def test__compare_to_imaging_util(self):
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(4, 3), grid=np.ones((2, 2))
             )
 
-            mapper = aa.mapper(grid=None, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=None, pixelization_grid=pixelization_grid)
 
             solution = np.array(
                 [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
@@ -588,11 +588,11 @@ class TestRectangularMapper:
             assert (recon_pix.in_2d == recon_pix_util).all()
             assert recon_pix.shape_2d == (4, 3)
 
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 4), grid=np.ones((2, 2))
             )
 
-            mapper = aa.mapper(grid=None, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=None, pixelization_grid=pixelization_grid)
 
             solution = np.array(
                 [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
@@ -610,11 +610,11 @@ class TestRectangularMapper:
 
     class TestPixelSignals:
         def test__pixel_signals__compare_to_mapper_util(self, grid_7x7, image_7x7):
-            pixelization_grid = aa.grid_rectangular.overlay_grid(
+            pixelization_grid = aa.GridRectangular.overlay_grid(
                 shape_2d=(3, 3), grid=grid_7x7
             )
 
-            mapper = aa.mapper(
+            mapper = aa.Mapper(
                 grid=grid_7x7,
                 pixelization_grid=pixelization_grid,
                 hyper_image=image_7x7,
@@ -635,10 +635,10 @@ class TestRectangularMapper:
     class TestImagePixelIndexesFromSourcePixelIndexes:
         def test__image_from_source__different_types_of_lists_input(self, sub_grid_7x7):
 
-            rectangular_pixelization_grid = aa.grid_rectangular.overlay_grid(
+            rectangular_pixelization_grid = aa.GridRectangular.overlay_grid(
                 grid=sub_grid_7x7, shape_2d=(3, 3)
             )
-            rectangular_mapper = aa.mapper(
+            rectangular_mapper = aa.Mapper(
                 grid=sub_grid_7x7, pixelization_grid=rectangular_pixelization_grid
             )
 
@@ -751,12 +751,12 @@ class TestVoronoiMapper:
                 [0, 0, 1, 0, 0, 1, 2, 2, 3]
             )
 
-            pixelization_grid = aa.grid_voronoi(
+            pixelization_grid = aa.GridVoronoi(
                 grid_1d=pixelization_grid,
                 nearest_pixelization_1d_index_for_mask_1d_index=nearest_pixelization_1d_index_for_mask_1d_index,
             )
 
-            mapper = aa.mapper(grid=grid_7x7, pixelization_grid=pixelization_grid)
+            mapper = aa.Mapper(grid=grid_7x7, pixelization_grid=pixelization_grid)
 
             assert (
                 mapper.pixelization_1d_index_for_sub_mask_1d_index
@@ -773,12 +773,12 @@ class TestVoronoiMapper:
                 [0, 0, 1, 0, 0, 1, 2, 2, 3]
             )
 
-            pixelization_grid = aa.grid_voronoi(
+            pixelization_grid = aa.GridVoronoi(
                 grid_1d=pixelization_grid,
                 nearest_pixelization_1d_index_for_mask_1d_index=nearest_pixelization_1d_index_for_mask_1d_index,
             )
 
-            mapper = aa.mapper(
+            mapper = aa.Mapper(
                 grid=grid_7x7,
                 pixelization_grid=pixelization_grid,
                 hyper_image=image_7x7,
