@@ -8,28 +8,26 @@ import autoarray as aa
 from autoarray.structures import arrays
 from autoarray import exc
 
-test_data_dir = "{}/../test_files/array/".format(
-    os.path.dirname(os.path.realpath(__file__))
-)
+test_data_dir = "{}/files/array/".format(os.path.dirname(os.path.realpath(__file__)))
 
 
 class TestArrayAPI:
     class TestManual:
         def test__array__makes_array_without_other_inputs(self):
 
-            arr = aa.array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]])
+            arr = aa.Array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]])
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
             assert (arr.in_1d == np.array([1.0, 2.0, 3.0, 4.0])).all()
 
-            arr = aa.array.manual_1d(array=[1.0, 2.0, 3.0, 4.0], shape_2d=(2, 2))
+            arr = aa.Array.manual_1d(array=[1.0, 2.0, 3.0, 4.0], shape_2d=(2, 2))
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
             assert (arr.in_1d == np.array([1.0, 2.0, 3.0, 4.0])).all()
 
-            arr = aa.array.manual_1d(
+            arr = aa.Array.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0, 5.0, 6.0], shape_2d=(2, 3), store_in_1d=True
             )
 
@@ -38,7 +36,7 @@ class TestArrayAPI:
             assert (arr.in_2d == np.array([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0]])).all()
             assert (arr.in_1d == np.array([1.0, 2.0, 3.0, 4.0, 5.0, 6.0])).all()
 
-            arr = aa.array.manual_1d(
+            arr = aa.Array.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0, 5.0, 6.0], shape_2d=(2, 3), store_in_1d=False
             )
 
@@ -49,7 +47,7 @@ class TestArrayAPI:
 
         def test__array__makes_array_with_pixel_scale(self):
 
-            arr = aa.array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], pixel_scales=1.0)
+            arr = aa.Array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], pixel_scales=1.0)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
@@ -57,7 +55,7 @@ class TestArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            arr = aa.array.manual_1d(
+            arr = aa.Array.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0],
                 shape_2d=(2, 2),
                 pixel_scales=1.0,
@@ -70,7 +68,7 @@ class TestArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 1.0)
 
-            arr = aa.array.manual_1d(
+            arr = aa.Array.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0, 5.0, 6.0],
                 shape_2d=(2, 3),
                 pixel_scales=(2.0, 3.0),
@@ -84,7 +82,7 @@ class TestArrayAPI:
 
         def test__array__makes_with_pixel_scale_and_sub_size(self):
 
-            arr = aa.array.manual_2d(
+            arr = aa.Array.manual_2d(
                 array=[[1.0, 2.0], [3.0, 4.0]], pixel_scales=1.0, sub_size=1
             )
 
@@ -95,7 +93,7 @@ class TestArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 1
 
-            arr = aa.array.manual_1d(
+            arr = aa.Array.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0],
                 shape_2d=(1, 1),
                 pixel_scales=1.0,
@@ -110,7 +108,7 @@ class TestArrayAPI:
             assert arr.geometry.origin == (0.0, 1.0)
             assert arr.mask.sub_size == 2
 
-            arr = aa.array.manual_1d(
+            arr = aa.Array.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0],
                 shape_2d=(2, 1),
                 pixel_scales=2.0,
@@ -133,20 +131,20 @@ class TestArrayAPI:
     class TestFull:
         def test__array__makes_array_without_other_inputs(self):
 
-            arr = aa.array.full(fill_value=1.0, shape_2d=(2, 2))
+            arr = aa.Array.ones(shape_2d=(2, 2))
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
             assert (arr.in_1d == np.array([1.0, 1.0, 1.0, 1.0])).all()
 
-            arr = aa.array.full(fill_value=2.0, shape_2d=(2, 2), store_in_1d=True)
+            arr = aa.Array.full(fill_value=2.0, shape_2d=(2, 2), store_in_1d=True)
 
             assert type(arr) == arrays.Array
             assert (arr == np.array([2.0, 2.0, 2.0, 2.0])).all()
             assert (arr.in_2d == np.array([[2.0, 2.0], [2.0, 2.0]])).all()
             assert (arr.in_1d == np.array([2.0, 2.0, 2.0, 2.0])).all()
 
-            arr = aa.array.full(fill_value=2.0, shape_2d=(2, 2), store_in_1d=False)
+            arr = aa.Array.full(fill_value=2.0, shape_2d=(2, 2), store_in_1d=False)
 
             assert type(arr) == arrays.Array
             assert (arr == np.array([[2.0, 2.0], [2.0, 2.0]])).all()
@@ -155,7 +153,7 @@ class TestArrayAPI:
 
         def test__array__makes_scaled_array_with_pixel_scale(self):
 
-            arr = aa.array.full(fill_value=1.0, shape_2d=(2, 2), pixel_scales=1.0)
+            arr = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
@@ -163,7 +161,7 @@ class TestArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            arr = aa.array.full(
+            arr = aa.Array.full(
                 fill_value=2.0, shape_2d=(2, 2), pixel_scales=1.0, origin=(0.0, 1.0)
             )
 
@@ -175,7 +173,7 @@ class TestArrayAPI:
 
         def test__array__makes_scaled_sub_array_with_pixel_scale_and_sub_size(self):
 
-            arr = aa.array.full(
+            arr = aa.Array.full(
                 fill_value=1.0, shape_2d=(1, 4), pixel_scales=1.0, sub_size=1
             )
 
@@ -186,7 +184,7 @@ class TestArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 1
 
-            arr = aa.array.full(
+            arr = aa.Array.full(
                 fill_value=2.0,
                 shape_2d=(1, 1),
                 pixel_scales=1.0,
@@ -204,20 +202,20 @@ class TestArrayAPI:
     class TestOnesZeros:
         def test__array__makes_array_without_other_inputs(self):
 
-            arr = aa.array.ones(shape_2d=(2, 2))
+            arr = aa.Array.ones(shape_2d=(2, 2))
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
             assert (arr.in_1d == np.array([1.0, 1.0, 1.0, 1.0])).all()
 
-            arr = aa.array.zeros(shape_2d=(2, 2), store_in_1d=True)
+            arr = aa.Array.zeros(shape_2d=(2, 2), store_in_1d=True)
 
             assert type(arr) == arrays.Array
             assert (arr == np.array([0.0, 0.0, 0.0, 0.0])).all()
             assert (arr.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
             assert (arr.in_1d == np.array([0.0, 0.0, 0.0, 0.0])).all()
 
-            arr = aa.array.zeros(shape_2d=(2, 2), store_in_1d=False)
+            arr = aa.Array.zeros(shape_2d=(2, 2), store_in_1d=False)
 
             assert type(arr) == arrays.Array
             assert (arr == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
@@ -226,7 +224,7 @@ class TestArrayAPI:
 
         def test__array__makes_scaled_array_with_pixel_scale(self):
 
-            arr = aa.array.ones(shape_2d=(2, 2), pixel_scales=1.0)
+            arr = aa.Array.ones(shape_2d=(2, 2), pixel_scales=1.0)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
@@ -234,7 +232,7 @@ class TestArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            arr = aa.array.zeros(shape_2d=(2, 2), pixel_scales=1.0, origin=(0.0, 1.0))
+            arr = aa.Array.zeros(shape_2d=(2, 2), pixel_scales=1.0, origin=(0.0, 1.0))
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
@@ -244,7 +242,7 @@ class TestArrayAPI:
 
         def test__array__makes_scaled_sub_array_with_pixel_scale_and_sub_size(self):
 
-            arr = aa.array.ones(shape_2d=(1, 4), pixel_scales=1.0, sub_size=1)
+            arr = aa.Array.ones(shape_2d=(1, 4), pixel_scales=1.0, sub_size=1)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0, 1.0, 1.0]])).all()
@@ -253,7 +251,7 @@ class TestArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 1
 
-            arr = aa.array.zeros(
+            arr = aa.Array.zeros(
                 shape_2d=(1, 1), pixel_scales=1.0, sub_size=2, origin=(0.0, 1.0)
             )
 
@@ -267,13 +265,13 @@ class TestArrayAPI:
     class TestFromFits:
         def test__array__makes_array_without_other_inputs(self):
 
-            arr = aa.array.from_fits(file_path=test_data_dir + "3x3_ones.fits", hdu=0)
+            arr = aa.Array.from_fits(file_path=test_data_dir + "3x3_ones.fits", hdu=0)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.ones((3, 3))).all()
             assert (arr.in_1d == np.ones(9)).all()
 
-            arr = aa.array.from_fits(
+            arr = aa.Array.from_fits(
                 file_path=test_data_dir + "4x3_ones.fits", hdu=0, store_in_1d=True
             )
 
@@ -282,7 +280,7 @@ class TestArrayAPI:
             assert (arr.in_2d == np.ones((4, 3))).all()
             assert (arr.in_1d == np.ones((12,))).all()
 
-            arr = aa.array.from_fits(
+            arr = aa.Array.from_fits(
                 file_path=test_data_dir + "4x3_ones.fits", hdu=0, store_in_1d=False
             )
 
@@ -293,7 +291,7 @@ class TestArrayAPI:
 
         def test__array__makes_scaled_array_with_pixel_scale(self):
 
-            arr = aa.array.from_fits(
+            arr = aa.Array.from_fits(
                 file_path=test_data_dir + "3x3_ones.fits", hdu=0, pixel_scales=1.0
             )
 
@@ -303,7 +301,7 @@ class TestArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            arr = aa.array.from_fits(
+            arr = aa.Array.from_fits(
                 file_path=test_data_dir + "4x3_ones.fits",
                 hdu=0,
                 pixel_scales=1.0,
@@ -318,7 +316,7 @@ class TestArrayAPI:
 
         def test__array__makes_scaled_sub_array_with_pixel_scale_and_sub_size(self):
 
-            arr = aa.array.from_fits(
+            arr = aa.Array.from_fits(
                 file_path=test_data_dir + "3x3_ones.fits",
                 hdu=0,
                 pixel_scales=1.0,
@@ -332,7 +330,7 @@ class TestArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 1
 
-            arr = aa.array.from_fits(
+            arr = aa.Array.from_fits(
                 file_path=test_data_dir + "4x3_ones.fits",
                 hdu=0,
                 pixel_scales=1.0,
@@ -352,8 +350,8 @@ class TestMaskedArrayAPI:
     class TestManual:
         def test__array__makes_array_with_pixel_scale(self):
 
-            mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
-            arr = aa.masked_array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], mask=mask)
+            mask = aa.Mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
+            arr = aa.MaskedArray.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
@@ -361,12 +359,12 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False, False], [True, False]],
                 pixel_scales=1.0,
                 origin=(0.0, 1.0),
             )
-            arr = aa.masked_array.manual_1d(array=[1.0, 2.0, 4.0], mask=mask)
+            arr = aa.MaskedArray.manual_1d(array=[1.0, 2.0, 4.0], mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 2.0], [0.0, 4.0]])).all()
@@ -374,12 +372,12 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 1.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False, False], [True, False]],
                 pixel_scales=1.0,
                 origin=(0.0, 1.0),
             )
-            arr = aa.masked_array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], mask=mask)
+            arr = aa.MaskedArray.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 2.0], [0.0, 4.0]])).all()
@@ -387,10 +385,10 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 1.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False], [True]], pixel_scales=2.0, sub_size=2
             )
-            arr = aa.masked_array.manual_1d(
+            arr = aa.MaskedArray.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0], mask=mask, store_in_1d=True
             )
 
@@ -406,7 +404,7 @@ class TestMaskedArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 2
 
-            arr = aa.masked_array.manual_1d(
+            arr = aa.MaskedArray.manual_1d(
                 array=[1.0, 2.0, 3.0, 4.0], mask=mask, store_in_1d=False
             )
 
@@ -429,16 +427,16 @@ class TestMaskedArrayAPI:
         ):
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=1)
-                aa.masked_array.manual_2d(array=[[1.0], [3.0]], mask=mask)
+                mask = aa.Mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=1)
+                aa.MaskedArray.manual_2d(array=[[1.0], [3.0]], mask=mask)
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=2)
-                aa.masked_array.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], mask=mask)
+                mask = aa.Mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=2)
+                aa.MaskedArray.manual_2d(array=[[1.0, 2.0], [3.0, 4.0]], mask=mask)
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=2)
-                aa.masked_array.manual_2d(
+                mask = aa.Mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0, sub_size=2)
+                aa.MaskedArray.manual_2d(
                     array=[[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]], mask=mask
                 )
 
@@ -447,30 +445,30 @@ class TestMaskedArrayAPI:
         ):
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.manual(
+                mask = aa.Mask.manual(
                     mask_2d=[[False, False], [True, False]], sub_size=1
                 )
-                aa.masked_array.manual_1d(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
+                aa.MaskedArray.manual_1d(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.manual(
+                mask = aa.Mask.manual(
                     mask_2d=[[False, False], [True, False]], sub_size=1
                 )
-                aa.masked_array.manual_1d(array=[1.0, 2.0], mask=mask)
+                aa.MaskedArray.manual_1d(array=[1.0, 2.0], mask=mask)
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.manual(mask_2d=[[False, True], [True, True]], sub_size=2)
-                aa.masked_array.manual_1d(array=[1.0, 2.0, 4.0], mask=mask)
+                mask = aa.Mask.manual(mask_2d=[[False, True], [True, True]], sub_size=2)
+                aa.MaskedArray.manual_1d(array=[1.0, 2.0, 4.0], mask=mask)
 
             with pytest.raises(exc.ArrayException):
-                mask = aa.mask.manual(mask_2d=[[False, True], [True, True]], sub_size=2)
-                aa.masked_array.manual_1d(array=[1.0, 2.0, 3.0, 4.0, 5.0], mask=mask)
+                mask = aa.Mask.manual(mask_2d=[[False, True], [True, True]], sub_size=2)
+                aa.MaskedArray.manual_1d(array=[1.0, 2.0, 3.0, 4.0, 5.0], mask=mask)
 
     class TestFull:
         def test__makes_array_using_mask(self):
 
-            mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
-            arr = aa.masked_array.full(fill_value=1.0, mask=mask)
+            mask = aa.Mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
+            arr = aa.MaskedArray.ones(mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
@@ -478,12 +476,12 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False, False], [True, False]],
                 pixel_scales=1.0,
                 origin=(0.0, 1.0),
             )
-            arr = aa.masked_array.full(fill_value=2.0, mask=mask)
+            arr = aa.MaskedArray.full(fill_value=2.0, mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[2.0, 2.0], [0.0, 2.0]])).all()
@@ -491,10 +489,10 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 1.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False], [True]], pixel_scales=2.0, sub_size=2
             )
-            arr = aa.masked_array.full(fill_value=3.0, mask=mask, store_in_1d=True)
+            arr = aa.MaskedArray.full(fill_value=3.0, mask=mask, store_in_1d=True)
 
             assert type(arr) == arrays.Array
             assert (arr == np.array([3.0, 3.0, 3.0, 3.0])).all()
@@ -508,7 +506,7 @@ class TestMaskedArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 2
 
-            arr = aa.masked_array.full(fill_value=3.0, mask=mask, store_in_1d=False)
+            arr = aa.MaskedArray.full(fill_value=3.0, mask=mask, store_in_1d=False)
 
             assert type(arr) == arrays.Array
             assert (
@@ -527,8 +525,8 @@ class TestMaskedArrayAPI:
     class TestOnesZeros:
         def test__makes_array_using_mask(self):
 
-            mask = aa.mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
-            arr = aa.masked_array.ones(mask=mask)
+            mask = aa.Mask.unmasked(shape_2d=(2, 2), pixel_scales=1.0)
+            arr = aa.MaskedArray.ones(mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[1.0, 1.0], [1.0, 1.0]])).all()
@@ -536,12 +534,12 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 0.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False, False], [True, False]],
                 pixel_scales=1.0,
                 origin=(0.0, 1.0),
             )
-            arr = aa.masked_array.zeros(mask=mask)
+            arr = aa.MaskedArray.zeros(mask=mask)
 
             assert type(arr) == arrays.Array
             assert (arr.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
@@ -549,10 +547,10 @@ class TestMaskedArrayAPI:
             assert arr.pixel_scales == (1.0, 1.0)
             assert arr.geometry.origin == (0.0, 1.0)
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=[[False], [True]], pixel_scales=2.0, sub_size=2
             )
-            arr = aa.masked_array.ones(mask=mask, store_in_1d=True)
+            arr = aa.MaskedArray.ones(mask=mask, store_in_1d=True)
 
             assert type(arr) == arrays.Array
             assert (arr == np.array([1.0, 1.0, 1.0, 1.0])).all()
@@ -566,7 +564,7 @@ class TestMaskedArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 2
 
-            arr = aa.masked_array.ones(mask=mask, store_in_1d=False)
+            arr = aa.MaskedArray.ones(mask=mask, store_in_1d=False)
 
             assert type(arr) == arrays.Array
             assert (
@@ -585,8 +583,8 @@ class TestMaskedArrayAPI:
     class TestFromFits:
         def test__array_from_fits_uses_mask(self):
 
-            mask = aa.mask.unmasked(shape_2d=(3, 3), pixel_scales=1.0)
-            arr = aa.masked_array.from_fits(
+            mask = aa.Mask.unmasked(shape_2d=(3, 3), pixel_scales=1.0)
+            arr = aa.MaskedArray.from_fits(
                 file_path=test_data_dir + "3x3_ones.fits", hdu=0, mask=mask
             )
 
@@ -597,7 +595,7 @@ class TestMaskedArrayAPI:
             assert arr.geometry.origin == (0.0, 0.0)
             assert arr.mask.sub_size == 1
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 [
                     [False, False, False],
                     [False, False, False],
@@ -607,7 +605,7 @@ class TestMaskedArrayAPI:
                 pixel_scales=1.0,
                 origin=(0.0, 1.0),
             )
-            arr = aa.masked_array.from_fits(
+            arr = aa.MaskedArray.from_fits(
                 file_path=test_data_dir + "4x3_ones.fits",
                 hdu=0,
                 mask=mask,
@@ -632,7 +630,7 @@ class TestMaskedArrayAPI:
             assert arr.geometry.origin == (0.0, 1.0)
             assert arr.mask.sub_size == 1
 
-            arr = aa.masked_array.from_fits(
+            arr = aa.MaskedArray.from_fits(
                 file_path=test_data_dir + "4x3_ones.fits",
                 hdu=0,
                 mask=mask,
@@ -914,7 +912,48 @@ class TestArray:
             assert (arr.in_2d == arr_resized_manual).all()
             assert arr.mask.pixel_scales == (1.0, 1.0)
 
-        def test__kernel_trim__trim_edges_where_extra_psf_blurring_is_performed(self):
+        def test__padded_from_kernel_shape__padded_edge_of_zeros_where_extra_psf_blurring_is_performed(
+            self
+        ):
+
+            array_2d = np.ones((5, 5))
+            array_2d[2, 2] = 2.0
+
+            arr = arrays.Array.manual_2d(
+                array=array_2d, sub_size=1, pixel_scales=(1.0, 1.0)
+            )
+
+            new_arr = arr.padded_from_kernel_shape(kernel_shape_2d=(3, 3))
+
+            assert type(new_arr) == arrays.Array
+            assert new_arr.in_2d[0, 0] == 0.0
+            assert new_arr.shape_2d == (7, 7)
+            assert new_arr.mask.pixel_scales == (1.0, 1.0)
+
+            new_arr = arr.padded_from_kernel_shape(kernel_shape_2d=(5, 5))
+
+            assert type(new_arr) == arrays.Array
+            assert new_arr.in_2d[0, 0] == 0.0
+            assert new_arr.shape_2d == (9, 9)
+            assert new_arr.mask.pixel_scales == (1.0, 1.0)
+
+            array_2d = np.ones((9, 9))
+            array_2d[4, 4] = 2.0
+
+            arr = arrays.Array.manual_2d(
+                array=array_2d, sub_size=1, pixel_scales=(1.0, 1.0)
+            )
+
+            new_arr = arr.padded_from_kernel_shape(kernel_shape_2d=(7, 7))
+
+            assert type(new_arr) == arrays.Array
+            assert new_arr.in_2d[0, 0] == 0.0
+            assert new_arr.shape_2d == (15, 15)
+            assert new_arr.mask.pixel_scales == (1.0, 1.0)
+
+        def test__trimmed_from_kernel_shape__trim_edges_where_extra_psf_blurring_is_performed(
+            self
+        ):
             array_2d = np.ones((5, 5))
             array_2d[2, 2] = 2.0
 
@@ -964,7 +1003,7 @@ class TestArray:
                 ]
             )
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, True, True, True],
@@ -977,13 +1016,13 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
 
             arr_zoomed = arr_masked.zoomed_around_mask(buffer=0)
 
             assert (arr_zoomed.in_2d == np.array([[6.0, 7.0], [10.0, 11.0]])).all()
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, True, True, True],
@@ -996,13 +1035,13 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
             arr_zoomed = arr_masked.zoomed_around_mask(buffer=0)
             assert (
                 arr_zoomed.in_2d == np.array([[6.0, 7.0, 8.0], [10.0, 11.0, 12.0]])
             ).all()
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, True, True, True],
@@ -1015,13 +1054,13 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
             arr_zoomed = arr_masked.zoomed_around_mask(buffer=0)
             assert (
                 arr_zoomed.in_2d == np.array([[6.0, 7.0], [10.0, 11.0], [14.0, 15.0]])
             ).all()
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, True, True, True],
@@ -1034,14 +1073,14 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
             arr_zoomed = arr_masked.zoomed_around_mask(buffer=0)
 
             assert (
                 arr_zoomed.in_2d == np.array([[0.0, 6.0, 7.0], [9.0, 10.0, 11.0]])
             ).all()
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, False, True, True],
@@ -1054,13 +1093,13 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
             arr_zoomed = arr_masked.zoomed_around_mask(buffer=0)
             assert (
                 arr_zoomed.in_2d == np.array([[2.0, 0.0], [6.0, 7.0], [10.0, 11.0]])
             ).all()
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, True, True, True],
@@ -1073,7 +1112,7 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
             arr_zoomed = arr_masked.zoomed_around_mask(buffer=1)
 
             assert (
@@ -1099,7 +1138,7 @@ class TestArray:
                 ]
             )
 
-            mask = aa.mask.manual(
+            mask = aa.Mask.manual(
                 mask_2d=np.array(
                     [
                         [True, True, True, False],
@@ -1112,7 +1151,7 @@ class TestArray:
                 sub_size=1,
             )
 
-            arr_masked = aa.masked_array.manual_2d(array=array_2d, mask=mask)
+            arr_masked = aa.MaskedArray.manual_2d(array=array_2d, mask=mask)
 
             extent = arr_masked.extent_of_zoomed_array(buffer=1)
 
@@ -1172,9 +1211,9 @@ class TestArray:
     class TestOutputToFits:
         def test__output_to_fits(self):
 
-            arr = aa.array.from_fits(file_path=test_data_dir + "3x3_ones.fits", hdu=0)
+            arr = aa.Array.from_fits(file_path=test_data_dir + "3x3_ones.fits", hdu=0)
 
-            output_data_dir = "{}/../test_files/array/output_test/".format(
+            output_data_dir = "{}/files/array/output_test/".format(
                 os.path.dirname(os.path.realpath(__file__))
             )
             if os.path.exists(output_data_dir):
@@ -1184,7 +1223,7 @@ class TestArray:
 
             arr.output_to_fits(file_path=output_data_dir + "array.fits")
 
-            array_from_out = aa.array.from_fits(
+            array_from_out = aa.Array.from_fits(
                 file_path=output_data_dir + "array.fits", hdu=0
             )
 
@@ -1192,9 +1231,9 @@ class TestArray:
 
         def test__output_to_fits__shapes_of_arrays_are_2d(self):
 
-            arr = aa.array.from_fits(file_path=test_data_dir + "3x3_ones.fits", hdu=0)
+            arr = aa.Array.from_fits(file_path=test_data_dir + "3x3_ones.fits", hdu=0)
 
-            output_data_dir = "{}/../test_files/array/output_test/".format(
+            output_data_dir = "{}/files/array/output_test/".format(
                 os.path.dirname(os.path.realpath(__file__))
             )
             if os.path.exists(output_data_dir):
@@ -1210,9 +1249,9 @@ class TestArray:
 
             assert (array_from_out == np.ones((3, 3))).all()
 
-            mask = aa.mask.unmasked(shape_2d=(3, 3), pixel_scales=0.1)
+            mask = aa.Mask.unmasked(shape_2d=(3, 3), pixel_scales=0.1)
 
-            masked_array = aa.masked_array(array=arr, mask=mask)
+            masked_array = aa.MaskedArray(array=arr, mask=mask)
 
             masked_array.output_to_fits(file_path=output_data_dir + "masked_array.fits")
 
